@@ -27,6 +27,7 @@
 # coldwar
 # casia
 # gfriends
+# htmanagers
 
 #' @title Null distribution plot
 #' 
@@ -392,7 +393,7 @@ circplot<-function(Y,U=NULL,V=NULL,row.names=rownames(Y),col.names=colnames(Y),
 #' netplot(Y,X) 
 #' 
 #' @export xnet
-xnet<-function(Y,fm=suppressWarnings(require(network)),seed=1)
+xnet<-function(Y,fm=suppressWarnings(require("network")),seed=1)
 {
   if(!is.null(seed)) { set.seed(seed) }
   if(fm)
@@ -407,7 +408,7 @@ xnet<-function(Y,fm=suppressWarnings(require(network)),seed=1)
   if(!fm)
   {
     Y0<-Y ; diag(Y0)<-1
-    U<-eigen(Y0)$vec[,1:2]
+    U<-Re(eigen(Y0)$vec[,1:2])
   }
   U<-sweep(U,2,apply(U,2,mean)) ; U<-sweep(U,2,apply(U,2,sd),"/")
   U
@@ -860,18 +861,59 @@ NULL
 #' @title Girls high school friendship data
 #'
 #' @description 
-#' Directed inditicaor of friendship between 144 high school girls 
+#' Directed inditicator of friendship between 144 high school girls 
 #'
 #' @format 
 #' A list including the following dyadic and nodal variables:
 #' \itemize{
 #' \item \code{Y}: an undirected sociomatrix of friendship ties;
-#' \item \code{X}: nodal covariates including grade and normalized gpa and smoking scores
+#' \item \code{X}: nodal covariates including grade and normalized gpa and smoking scores.
 #' }
 #' 
 #' @name gfriends
 NULL
 
 
+#' @title Krackhardt's  high-tech managers 
+#'
+#' @description 
+#' Self-reported binary relations among 21 managers of a high-tech
+#' company, as well as several nodal attributes. 
+#'
+#' @format 
+#' A list consisting of the following:
+#' \itemize{
+#' \item \code{Y}: a directed socioarray representing to whom the ego 
+#'  goes to for advice, whom the ego considers a friend, and to whom the 
+#'  ego reports to. 
+#' \item \code{X}: nodal covariates including age, length of service, level in the corporate hierarchy and department. 
+#' }
+#' 
+#' @source 
+#' \url{http://moreno.ss.uci.edu/data.html#krackht}
+#' @name htmanagers
+NULL
+
+
+#' @title Sheep dominance data
+#'
+#' @description 
+#' Number of dominance encounters between 28 female bighorn sheep. 
+#' Cell (i,j) records the number of times sheep i dominated sheep j. 
+#' From Hass (1991). 
+#'  
+#' @format 
+#' A list consisting of the following:
+#' \itemize{
+#' \item \code{dom}: a directed socioarray recording the number of 
+#' dominance encounters. 
+#' \item \code{age}: the age of each sheep in years. 
+#' }
+#' 
+#' @source 
+#' \url{http://moreno.ss.uci.edu/data.html#sheep}
+#' @name sheep
+NULL
+
 
 
